package hu.bute.daai.amorg.examples;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLEncoder;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.HttpStatus;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.BasicResponseHandler;
import org.json.JSONException;
import org.json.JSONObject;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;

import android.app.Activity;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.http.AndroidHttpClient;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

public class HttpDemoActivity extends Activity {

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		// --- Basic HTTP GET
		Button btnHttpBasicGet = (Button) findViewById(R.id.btnHttpBasicGet);
		btnHttpBasicGet.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View arg0) {
				new Thread() {
					public void run() {
						httpBasicGetDemo();
					}
				}.start();
			}
		});

		// --- Standard HTTP GET
		Button btnHttpGet = (Button) findViewById(R.id.btnHttpGet);
		btnHttpGet.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View arg0) {
				new Thread() {
					public void run() {
						httpGetDemo();
					}
				}.start();
			}
		});

		// --- HTTP GET with AsyncTask
		Button btnHttpGetAsync = (Button) findViewById(R.id.btnHttpGetAsync);
		btnHttpGetAsync.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View arg0) {
				String name = "John Doe";
				name = URLEncoder.encode(name);
				String url = "http://avalon.aut.bme.hu/~tyrael/phpget.php?name="
						+ name;
				new HttpGetAsyncTask(HttpDemoActivity.this).execute(url);
			}
		});

		// --- JSON
		Button btnJSON = (Button) findViewById(R.id.btnJSON);
		btnJSON.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View arg0) {
				new Thread() {
					public void run() {
						processJSON();
					}
				}.start();
			}
		});

		// --- XML
		Button btnXML = (Button) findViewById(R.id.btnXML);
		btnXML.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View arg0) {
				new Thread() {
					public void run() {
						processXML((LinearLayout) findViewById(R.id.layoutMain));
					}
				}.start();
			}
		});
	}

	private void httpBasicGetDemo() {
		AndroidHttpClient httpClient = null;
		try {
			httpClient = AndroidHttpClient
					.newInstance("Android");
			String name = "John Doe";
			name = URLEncoder.encode(name);
			HttpGet httpGet = new HttpGet(
					"http://avalon.aut.bme.hu/~tyrael/phpget.php?name=" + name);
			final String resp = httpClient.execute(httpGet,
					new BasicResponseHandler());
			runOnUiThread(new Runnable() {
				@Override
				public void run() {
					Toast.makeText(HttpDemoActivity.this, resp,
							Toast.LENGTH_LONG).show();
				}
			});
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			if (httpClient != null)
				httpClient.close();
		}
	}

	private void httpGetDemo() {
		AndroidHttpClient httpClient = null;
		try {
			httpClient = AndroidHttpClient.newInstance("Android");
			String name = "John Doe";
			name = URLEncoder.encode(name);
			HttpGet httpGet = new HttpGet(
					"http://avalon.aut.bme.hu/~tyrael/phpget.php?name=" + name);
			HttpResponse response = httpClient.execute(httpGet);
			if (response.getStatusLine().getStatusCode() == HttpStatus.SC_OK) {
				HttpEntity entity = response.getEntity();
				if (entity != null) {
					InputStream is = entity.getContent();
					processResponse(is);
				}
			}
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			if (httpClient != null)
				httpClient.close();
		}
	}

	private void processResponse(final InputStream aIs) {
		runOnUiThread(new Runnable() {
			@Override
			public void run() {
				try {
					StringBuilder sb = new StringBuilder();
					int chIn;
					while ((chIn = aIs.read()) != -1) {
						sb.append((char) chIn);
					}
					Toast.makeText(HttpDemoActivity.this, sb.toString(),
							Toast.LENGTH_LONG).show();
				} catch (Exception e) {
					e.printStackTrace();
				} finally {
					if (aIs != null) {
						try {
							aIs.close();
						} catch (IOException e) {
							e.printStackTrace();
						}
					}
				}
			}
		});
	}

	private void processJSON() {
		AndroidHttpClient httpClient = null;
		try {
			httpClient = AndroidHttpClient
					.newInstance("Android");
			HttpGet httpGet = new HttpGet(
					"http://maps.googleapis.com/maps/api/geocode/json?"
							+ "address=Budapest%20Astoria&sensor=false");
			final String resp = httpClient.execute(httpGet,
					new BasicResponseHandler());

			// --- JSON feldolgozs
			JSONObject root = new JSONObject(resp);
			JSONObject location = root.getJSONArray("results").getJSONObject(0)
					.getJSONObject("geometry").getJSONObject("location");
			final String lat = location.getString("lat");
			final String lng = location.getString("lng");
			// ---

			runOnUiThread(new Runnable() {
				@Override
				public void run() {
					Toast.makeText(HttpDemoActivity.this, lat + "," + lng,
							Toast.LENGTH_LONG).show();
				}
			});
		} catch (JSONException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			if (httpClient != null)
				httpClient.close();
		}
	}

	private void processXML(final LinearLayout aBaseLayout) {
		try {
			URL url = new URL(
					"http://www.google.com/ig/api?weather=Budapest&hl=en");
			DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
			DocumentBuilder db = dbf.newDocumentBuilder();
			Document doc = db.parse(new InputSource(url.openStream()));
			doc.getDocumentElement().normalize();
			// Idjrs kiolvassa
			NodeList current_conditions = doc.
					getElementsByTagName("current_conditions");
			NodeList condition = ((Element) current_conditions.item(0)).
					getElementsByTagName("condition");
			final String weather = ((Element) condition.item(0)).
					getAttribute("data");
			// Ikon letltse
			NodeList icon = ((Element) current_conditions.item(0)).
					getElementsByTagName("icon");
			URL urlIcon = new URL("http://www.google.com"
					+ ((Element) icon.item(0)).getAttribute("data"));
			final Bitmap weatherIcon = BitmapFactory.decodeStream(urlIcon.
					openStream());
	
			runOnUiThread(new Runnable() {
				@Override
				public void run() {
					// Idjrs szvege
					TextView tvWeather = new TextView(HttpDemoActivity.this);
					tvWeather.setText(weather);
					tvWeather.setTextSize(30);
					aBaseLayout.addView(tvWeather);
					// Idjrs ikonja
					ImageView ivWeather = new ImageView(HttpDemoActivity.this);
					ivWeather.setImageBitmap(weatherIcon);
					aBaseLayout.addView(ivWeather);
				}
			});
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}