package amorg.android.intent;

import java.io.File;

import amorg.android.intent.entity.Todo;
import android.app.Activity;
import android.content.ActivityNotFoundException;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.ContactsContract;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.webkit.MimeTypeMap;
import android.widget.Button;
import android.widget.Toast;

/**
 * MainActivity
 *  
 * @author Feher Marcell [feher.marcell@aut.bme.hu]
 */
public class MainActivity extends Activity {
    
	Button gotoSecondActivityBtn, openRandomFileBtn, pickContactBtn;
	
	final int REQUEST_CONTACTPICK = 1;
	final int REQUEST_SECONDACTIVITY = 2;
	public static final int RESULT_CUSTOM = 1;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        // ez kotelezo, mivel az Activity osztalybol szarmaztattunk
    	super.onCreate(savedInstanceState);
        // legfelso szintu UI elem betoltese (layout)
    	setContentView(R.layout.main);
        
        // referencia szerzese UI elemekre
        gotoSecondActivityBtn = (Button) findViewById(R.id.gotoSecondActivity);
        openRandomFileBtn = (Button) findViewById(R.id.openRandomFile);
        pickContactBtn = (Button) findViewById(R.id.pickContact);
        
        // esemenykezelok bekotese az egyes gombokhoz
        // a konkret esemenykezelo fuggvenyek az onCreate() alatt
        gotoSecondActivityBtn.setOnClickListener(gotoSecondActivityClick);
        openRandomFileBtn.setOnClickListener(openRandomFileClick);
        pickContactBtn.setOnClickListener(pickContactClick);
        
    }
    
    OnClickListener gotoSecondActivityClick = new OnClickListener() {
    	public void onClick(View v) {
    		
    		Intent i = new Intent(getApplicationContext(), SecondActivity.class);
    		startActivityForResult(i, REQUEST_SECONDACTIVITY);
    	}
    };
    
    OnClickListener openRandomFileClick = new OnClickListener() {
    	public void onClick(View v) {
    		// referencia az SD kartya gyokerere 
    		// (ha fizikailag nincs kartya a telefonban, akkor is mukodik!)
    		File sdCard = Environment.getExternalStorageDirectory();
    		if(sdCard == null){
    			// emulator eseten lehet hogy meg ez sincs
    			Toast.makeText(getApplicationContext(), "Nincs nyilvnos trhely!", Toast.LENGTH_SHORT).show();
    			return;
    		}
    		File randomFile = null;
    		// kivalasztjuk az elso file-t
    		File[] filesOfExternalStorage = sdCard.listFiles(); 
    		if(filesOfExternalStorage == null){
    			Toast.makeText(getApplicationContext(), "Nincs fjl a nyilvnos trhelyen!", Toast.LENGTH_SHORT).show();
    			return;
    		}
    		for (File f : filesOfExternalStorage) {
    			if(f.isFile()){
    				randomFile = f;
    				break;
    			}
    		}
    		Toast.makeText(getApplicationContext(), randomFile.getName()+" megnyitasa...", Toast.LENGTH_SHORT).show();
    		
			Intent i = new Intent(Intent.ACTION_VIEW);
    		// segedvaltozo a file kiterjesztes meghatarozasahoz
    		// (szetvagjuk a filenevet a benne levo pontoknal)
    		// peldaul: az.en.kedvenc.filmjeim.doc => {"az", "en", "kedvenc", "filmjeim", "doc"}
    		String[] namePieces = randomFile.getName().split("\\.");
    		// a kiterjesztes ennek a tombnek az utolso eleme
    		String fileExtension = namePieces[(namePieces.length-1)];
    		// meghatarozzuk a MIME tipust a kiterjesztesbol
    		String mimeType = MimeTypeMap.getSingleton().getMimeTypeFromExtension(fileExtension);
    		// beallitjuk az Intent-ben kuldott adat Uri-jat es MIME tipusat
    		i.setDataAndType(Uri.fromFile(randomFile), mimeType);
    		try{
    			startActivity(i);
    		} catch (ActivityNotFoundException e) {
    			Toast.makeText(getApplicationContext(), "Nincs olyan alkalmazs teleptve, ami kezelni tudn a kivlasztott fjl tpust!", Toast.LENGTH_SHORT).show();
    		} catch (Exception ex){
    			Toast.makeText(getApplicationContext(), "Hiba trtnt!", Toast.LENGTH_SHORT).show();
    			Log.e("fileView", "Exception: " + ex.getMessage());
    		}
    	}
    };
    
    OnClickListener pickContactClick = new OnClickListener() {
		public void onClick(View v) {
			Intent i = new Intent(Intent.ACTION_PICK, ContactsContract.Contacts.CONTENT_URI);
			startActivityForResult(i, REQUEST_CONTACTPICK);
		}
	};
    
    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
    	switch (requestCode) {
			case REQUEST_SECONDACTIVITY:
				switch (resultCode) {
					case RESULT_OK:
						Toast.makeText(getApplicationContext(), "Visszatrsi rtk: OK", Toast.LENGTH_SHORT).show();
						break;
					case RESULT_CANCELED:
						Toast.makeText(getApplicationContext(), "Visszatrsi rtk: Cancel", Toast.LENGTH_SHORT).show();
						break;
					case RESULT_CUSTOM:
						// ha van benne "amorg.android.intent.parcel" kulcs, akkor Todo objektum jott 
						if(data.hasExtra(getPackageName()+".parcel")){
							// kivesszuk a Parcel-bol a Todo objektumot
							Todo fromExtra = (Todo)data.getParcelableExtra(getPackageName()+".parcel");
							Toast.makeText(getApplicationContext(), "Visszatrs: TODO("+fromExtra.getTitle()+", "+fromExtra.getDescription()+")", Toast.LENGTH_SHORT).show();
						}
						else{
							String returnValue1 = data.getStringExtra(getPackageName()+".string1");
							String returnValue2 = data.getStringExtra(getPackageName()+".string2");
							Toast.makeText(getApplicationContext(), "Visszatrsi rtk: "+returnValue1+ ((returnValue2!=null) ?  ", "+returnValue2 : ""), Toast.LENGTH_SHORT).show();
						}
						
						break;
						
					default:
						Toast.makeText(getApplicationContext(), "Ismeretlen visszatrsi rtk!", Toast.LENGTH_SHORT).show();
						break;
				}
				break;
				
			case REQUEST_CONTACTPICK:
				if(resultCode == RESULT_CANCELED)
					break;
				
				String msg = "";
				for (String key : data.getExtras().keySet()) {
					Log.v("EXTRA DATA", key +" => " + data.getExtras().get(key));
					msg += key +" => " + data.getExtras().get(key) + "\n";
				}
				Toast.makeText(getApplicationContext(), msg, Toast.LENGTH_SHORT).show();
				break;
	
			default:
				break;
		}
    	super.onActivityResult(requestCode, resultCode, data);
    }
    
    
}