package com.coreservlets.intentsexercises1;

import android.net.Uri;
import android.os.Bundle;
import android.widget.TextView;
import android.app.Activity;
import android.content.Intent;

public class SumActivity extends Activity {
    private double mInput1=3.4, mInput2=5.6;
    private String mMessageTemplate =
            "Sum of %.3f and %.3f is %.3f";
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_sum);
        setInputsFromExtras();
        setInputsFromUri();
        TextView sumView = (TextView)findViewById(R.id.sum_view);
        String message = String.format(mMessageTemplate, mInput1, mInput2, (mInput1 + mInput2));
        sumView.setText(message);
    }
    
    /** Sets the instance variables for input1 and input2 from the
     *  "extras" Bundle if it exists. If it exists, that means it was
     *  passed in from another Activity that invoked this one.
     */
    private void setInputsFromExtras() {
        Intent intent = getIntent();
        Bundle inputs = intent.getExtras();
        if (inputs != null) {
            double input1 = inputs.getDouble("input1");
            if  (input1 > 0) {
                mInput1 = input1;
            }
            double input2 = inputs.getDouble("input2");
            if  (input2 > 0) {
                mInput2 = input2;
            }
        }
    }
    
    /** Sets the instance variables for input1 and input2 from the
     *  URI query parameters, if they exist. If they exist, that means they
     *  were passed in on the end of the URI from another Activity that invoked this one.
     */
    private void setInputsFromUri() {
        Uri uri = getIntent().getData(); // null when Activity invoked by class name
        if (uri != null) {
            double input1 = getDoubleParam(uri, "input1");
            if  (input1 > 0) {
                mInput1 = input1;
            }
            double input2 = getDoubleParam(uri, "input2");
            if  (input2 > 0) {
                mInput2 = input2;
            }
        }
    }
    
    private double getDoubleParam(Uri uri, String queryParamName) {
        String rawValue = uri.getQueryParameter(queryParamName);
        double value = 0.0;
        try {
            value = Double.parseDouble(rawValue);
        } catch(Exception e) { } // NumberFormatException or NullPointerException
        return(value);
    }
}
