package bute.amorg.TelefoniaPelda;

import java.util.Date;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.telephony.CellLocation;
import android.telephony.PhoneStateListener;
import android.telephony.ServiceState;
import android.telephony.SignalStrength;
import android.telephony.TelephonyManager;
import android.telephony.gsm.GsmCellLocation;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

public class MainActivity extends Activity {
    
	Button callPhoneBtn, dialPhoneBtn;
	TextView telephonyLog;
	EditText phoneNumber;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        // UI elemek referenciai
        setupUIReferences();
        
        // a telefonszam feldolgozo gombokra ugyanazt az esemenykezelot kotjuk be
        // majd ott eldontjuk hogy mit kell csinalni a telefonszammal
        callPhoneBtn.setOnClickListener(callPhoneClick);
        dialPhoneBtn.setOnClickListener(callPhoneClick);
        
        // a fenti gombokat csak akkor aktivaljuk, ha a telefonszam mezo nem ures
        phoneNumber.addTextChangedListener(new TextWatcher() {
			
			@Override
			public void onTextChanged(CharSequence s, int start, int before, int count) { }
			
			@Override
			public void beforeTextChanged(CharSequence s, int start, int count, int after) { }
			
			@Override
			public void afterTextChanged(Editable s) {
				if(s.length()>0){
					callPhoneBtn.setEnabled(true);
					dialPhoneBtn.setEnabled(true);
				}
				else{
					callPhoneBtn.setEnabled(false);
					dialPhoneBtn.setEnabled(false);
				}
					
			}
		});
        
        // PhoneStateListener callback fuggvenyek 
        PhoneStateListener psl = setupPhoneStateListener();
        
        TelephonyManager tm = (TelephonyManager) getSystemService(Context.TELEPHONY_SERVICE);
		
        tm.listen(psl, 
        		PhoneStateListener.LISTEN_CALL_STATE | 
        		PhoneStateListener.LISTEN_SIGNAL_STRENGTHS |
        		PhoneStateListener.LISTEN_CALL_FORWARDING_INDICATOR |
        		PhoneStateListener.LISTEN_CELL_LOCATION |
        		PhoneStateListener.LISTEN_DATA_ACTIVITY |
        		PhoneStateListener.LISTEN_DATA_CONNECTION_STATE |
        		PhoneStateListener.LISTEN_MESSAGE_WAITING_INDICATOR |
        		PhoneStateListener.LISTEN_SERVICE_STATE |
        		PhoneStateListener.LISTEN_SIGNAL_STRENGTH
				);
		
        // TelephonyManager-tl kzvetlenl lekrdezhet pldul a SIM krtya llapota. 
		switch (tm.getSimState()) {

			case TelephonyManager.SIM_STATE_ABSENT:
				writeLog("Nincs SIM krtya a kszlkben");
				break;
	
			case TelephonyManager.SIM_STATE_NETWORK_LOCKED:
				writeLog("A mobilszolgltat letiltotta a krtyt");
				break;
	
			case TelephonyManager.SIM_STATE_PIN_REQUIRED:
				writeLog("PIN kd megadsa szksges, csak seglyhvsok");
				break;
	
			case TelephonyManager.SIM_STATE_PUK_REQUIRED:
				writeLog("PUK kd megadsa szksges, csak seglyhvsok");
				break;
	
			case TelephonyManager.SIM_STATE_READY:
				writeLog("A SIM krtya hasznlhat hvs indtsra s fogadsra");
				break;
	
			case TelephonyManager.SIM_STATE_UNKNOWN:
				writeLog("A krtya llapota nem meghatrozhat");
				break;

		}
    }
    
    OnClickListener callPhoneClick = new OnClickListener() {
		@Override
		public void onClick(View v) {
			// phoneNumber EditText-ben megadott telefonszam tarcsazasa vagy felhivasa
			String phoneNo = phoneNumber.getText().toString();
			Intent i = new Intent();
			i.setData(Uri.parse("tel:" + phoneNo));
			
			// hivas vagy tarcsazas attol fuggoen, hogy melyik gomb megnyomasara fut le ez a callback
			switch (v.getId()) {
			case R.id.callPhoneBtn:
				// ehhez kell a CALL_PHONE permission!
				i.setAction(Intent.ACTION_CALL);
				break;
			case R.id.dialPhoneBtn:
				i.setAction(Intent.ACTION_DIAL);
				break;
			default:
				break;
			}
			// hivas vagy tarcsazas kezdemenyezese implicit intent-el
			startActivity(i);
		}
	};
    
    private void writeLog(String msg){
    	Date now = new Date();
    	String time = now.getHours()+":"+now.getMinutes()+":"+now.getSeconds();
    	telephonyLog.append("["+time+"] "+msg+"\n");
    }
    
    private PhoneStateListener setupPhoneStateListener() {
    	
    	// ne felejtsuk el elkerni a kovetkezo permission-oket:
    	// READ_PHONE
    	// ACCESS_COARSE_LOCATION (onCellLocationChanged-hez)
    	
		PhoneStateListener psl = new PhoneStateListener() {

			@Override
			public void onCallForwardingIndicatorChanged(boolean cfi) {
				super.onCallForwardingIndicatorChanged(cfi);

				if (cfi) {
					writeLog("hvs tirnyts bekapcsolva");
					
				} else {
					writeLog("hvs tirnyts kikapcsolva");
				}

			}

			@Override
			public void onCallStateChanged(int state, String incomingNumber) {
				super.onCallStateChanged(state, incomingNumber);

				switch (state) {
					case TelephonyManager.CALL_STATE_RINGING:
						writeLog("j bejv hvs");
						writeLog("A hv telefonszma: " + incomingNumber);
						break;
	
					case TelephonyManager.CALL_STATE_OFFHOOK:
						writeLog("Egy vagy tbb hvs van folyamatban, lehet trcszs kzben, kapcsoldva vagy tartsban.");
						break;
	
					case TelephonyManager.CALL_STATE_IDLE:
						writeLog("Nincs aktivits a mobilhlzaton");
						break;

				}
			}

			@Override
			public void onDataActivity(int direction) {
				super.onDataActivity(direction);

				switch (direction) {
				case TelephonyManager.DATA_ACTIVITY_IN:
					writeLog("Letlts zajlik");
					break;

				case TelephonyManager.DATA_ACTIVITY_OUT:
					writeLog("Feltlts zajlik");
					break;

				case TelephonyManager.DATA_ACTIVITY_INOUT:
					writeLog("Mindkt irnyban trtnik adatforgalom");
					break;

				case TelephonyManager.DATA_ACTIVITY_NONE:
					writeLog("Nincs adatforgalom");
					break;

				case TelephonyManager.DATA_ACTIVITY_DORMANT:
					writeLog("Aktv adatforgalom, de a fizikai kapcsolat megszakadt");
					break;
				}

			}

			@Override
			public void onDataConnectionStateChanged(int state) {
				super.onDataConnectionStateChanged(state);

				switch (state) {
				case TelephonyManager.DATA_CONNECTING:
					writeLog("Mobilnet csatlakozs folyamatban");
					break;

				case TelephonyManager.DATA_CONNECTED:
					writeLog("Mobilnet kapcsoldva");
					break;

				case TelephonyManager.DATA_SUSPENDED:
					writeLog("A kapcsolat felfggesztve");
					break;

				case TelephonyManager.DATA_DISCONNECTED:
					writeLog("Nincs mobilnet kapcsolat");
					break;

				}

			}

			@Override
			public void onMessageWaitingIndicatorChanged(boolean mwi) {
				super.onMessageWaitingIndicatorChanged(mwi);

				if (mwi) {
					writeLog("Van j hangposta zenet");
				} else {
					writeLog("A hangposta zeneteket a felhasznl meghallgatta, nem vrakozik j zenet");
				}
			}

			@Override
			public void onCellLocationChanged(CellLocation location) {
				super.onCellLocationChanged(location);

				//kasztols GsmLocation objektumm
				GsmCellLocation gsmLocation = (GsmCellLocation) location;
				
				int cellId = gsmLocation.getCid();
				writeLog("j cella azonost: " + cellId);
				
				int locationAreaCode = gsmLocation.getLac();
				writeLog("j terlet azonost: " + locationAreaCode);
			}

			@Override
			public void onServiceStateChanged(ServiceState serviceState) {
				// Otthoni vagy klfldi hlzaton vagyunk
				boolean isRoaming = serviceState.getRoaming();
				if(isRoaming)
					writeLog("Roaming aktv");
				else
					writeLog("Roaming inaktv");
				
				// Hlzat vlaszts mdjnak aktulis belltsa
				boolean networkSelectionMode = serviceState
						.getIsManualSelection();
				if (networkSelectionMode == true) {
					writeLog("Kzi hlzatvlszts van belltva");
				} else {
					writeLog("Automatikus hlzatvlszts van belltva");
				}

				String operatorNameLong = serviceState.getOperatorAlphaLong();
				writeLog("Aktulis mobilhlzat szolgltatjnak hossz neve: " + operatorNameLong);

				String operatorNameShort = serviceState.getOperatorAlphaShort();
				writeLog("Aktulis mobilhlzat szolgltatjnak rvid neve: " + operatorNameShort);

				// Aktulis mobilhlzat szolgltatjnak numerikus kdja:
				// orszgkd (pontosan 3 szmjegy, Magyarorszg esetn 216) s
				// opertor kd (2 vagy 3 szmjegy, elhvszm, 20/30/70)
				// konkatenltja
				// pldul: 21630 (Telekom), 21620 (Telenor), 21670 (Vodafone)
				String operatorCode = serviceState.getOperatorNumeric();
				writeLog("Aktulis mobilhlzat szolgltatjnak kdja (MCC+MNC): " + operatorCode);
				
				
				switch (serviceState.getState()) {

				case ServiceState.STATE_EMERGENCY_ONLY:
					// Csak vszhvsok engedlyezettek (112, 911)
					writeLog("Kapcsoldva a mobilhlzathoz, de a SIM krtya le van zrva");
					break;

				case ServiceState.STATE_IN_SERVICE:
					// Minden hvs engedlyezett
					writeLog("Kapcsoldva a mobilhlzathoz, SIM krtya feloldva");
					break;

				case ServiceState.STATE_OUT_OF_SERVICE:
					writeLog("Nincs kapcsolat a mobilhlzattal");
					// A kvetkez esetekben fordulhat el:
					// A telefon pp keresi a szolgltatt ahova regisztrlhat
					// Egyltaln nem keres szolgltatt
					// A kivlasztott szolgltat visszautastotta a
					// regisztrcis krst
					// Nincs jel a mobilhlzatrl
					break;

				case ServiceState.STATE_POWER_OFF:
					writeLog("Mobilhlzati modul kikapcsolva");
					// Jellemzen "Replgp zemmd" esetn
					break;

				}

			}

			@Override
			public void onSignalStrengthsChanged(SignalStrength signalStrength) {

				// GSM hlzat hiba rtja (TS 27.007 8.5 szabvny szerint)
				int gsmErrorRate = signalStrength.getGsmBitErrorRate();
				writeLog("GSM hlzat hiba rtja: " + gsmErrorRate);
				
				// GSM jelerssg (TS 27.007 8.5 szabvny szerint)
				int gsmSignal = signalStrength.getGsmSignalStrength();
				writeLog("GSM jelerssg: " + gsmSignal);

				// CDMA hlzat esetn az RSSI rtk dBm-ben
				int cdmaRSSI = signalStrength.getCdmaDbm();
				writeLog("CDMA hlzat esetn az RSSI rtk dBm-ben: " + cdmaRSSI);

				// CDMA hlzat esetn az Ec/Io rtk, dB*10
				int cdmaEcIo = signalStrength.getCdmaEcio();
				writeLog("CDMA hlzat esetn az Ec/Io rtk, dB*10: " + cdmaEcIo);

				// EVDO hlzat esetn az RSSI rtk dBm-ben
				// (ez a hlzat tpus csak az USA-ban hasznlt)
				int evdoRSSI = signalStrength.getEvdoDbm();
				writeLog("EVDO hlzat esetn az RSSI rtk dBm-ben: " + evdoRSSI);

				// EVDO hlzat esetn az Ec/Io rtk, dB*10
				// (ez a hlzat tpus csak az USA-ban hasznlt)
				int evdoEcIo = signalStrength.getEvdoEcio();
				writeLog("EVDO hlzat esetn az Ec/Io rtk, dB*10: " + evdoEcIo);

				// EVDO hlzat esetn a jel-zaj arny
				// rtke 0-8 lehet, 8 a legnagyobb SNR
				// (ez a hlzat tpus csak az USA-ban hasznlt)
				int evdoSNR = signalStrength.getEvdoSnr();
				writeLog("EVDO hlzat esetn a jel-zaj arny: " + evdoSNR);
			}

		};
		return psl;
	}

	private void setupUIReferences() {
		callPhoneBtn = (Button) findViewById(R.id.callPhoneBtn);
        dialPhoneBtn = (Button) findViewById(R.id.dialPhoneBtn);
        
        telephonyLog = (TextView) findViewById(R.id.telephonyLog);
        
        phoneNumber = (EditText) findViewById(R.id.phoneNumber);
	}
}