package hu.bute.daai.amorg.examples;

import java.util.List;

import android.app.Activity;
import android.os.Bundle;
import android.telephony.NeighboringCellInfo;
import android.telephony.PhoneStateListener;
import android.telephony.SignalStrength;
import android.telephony.TelephonyManager;
import android.telephony.gsm.GsmCellLocation;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;

public class TelephonyDemoActivity extends Activity {

	private class MyPhoneStateListener extends PhoneStateListener {
		public void onSignalStrengthsChanged(SignalStrength signalStrength) {
			super.onSignalStrengthsChanged(signalStrength);
			tvStatus.setText("GSM Cinr = "+
					String.valueOf(signalStrength.getGsmSignalStrength()));
		}
		@Override
		public void onDataActivity(int direction) {
			super.onDataActivity(direction);
			tvStatus.setText("Data activity direction = "+
					direction);
		}
	};

	private TelephonyManager tm;
	private MyPhoneStateListener myPhoneStateListener = null;
	private TextView tvStatus;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		tm = (TelephonyManager) getSystemService(TELEPHONY_SERVICE);
		tvStatus = (TextView) findViewById(R.id.tvStatus);

		Button btnCIDLAC = (Button) findViewById(R.id.btnCIDLAC);
		btnCIDLAC.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				showCIDLAC();
			}
		});

		Button btnNCIDs = (Button) findViewById(R.id.btnNCIDs);
		btnNCIDs.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				showNeightBoringCells();
			}
		});

		Button btnTelephony = (Button) findViewById(R.id.btnTelephony);
		btnTelephony.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				showTelephonyInfo();
			}
		});

		Button btnStartListening = (Button) findViewById(
				R.id.btnStartListening);
		btnStartListening.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				startListening();
			}
		});
	}

	@Override
	protected void onStop() {
		super.onStop();
		if (myPhoneStateListener != null && tm != null)
			tm.listen(myPhoneStateListener, PhoneStateListener.LISTEN_NONE);
	}

	protected void startListening() {
		MyPhoneStateListener myListener = new MyPhoneStateListener();
		tm.listen(myListener,PhoneStateListener.LISTEN_DATA_ACTIVITY | PhoneStateListener.LISTEN_SIGNAL_STRENGTHS);
	}

	private void showCIDLAC() {
		GsmCellLocation loc = (GsmCellLocation) tm.getCellLocation();
		int cellId = loc.getCid();
		int lac = loc.getLac();
		tvStatus.setText("LAC: " + lac + ", " + " CellID: " + cellId);
	}

	private void showNeightBoringCells() {
		List<NeighboringCellInfo> cellinfo = tm.getNeighboringCellInfo();
		StringBuilder sb = new StringBuilder();
		for (NeighboringCellInfo info : cellinfo) {
			int cellId = info.getCid();
			int rssi = info.getRssi(); // jel-zaj
			sb.append("CellID: ");
			sb.append(cellId);
			sb.append(", ");
			sb.append("RSSI: ");
			sb.append(rssi);
			sb.append("\n");
		}
		tvStatus.setText(sb.toString());
	}

	private void showTelephonyInfo() {
		StringBuilder sb = new StringBuilder();
		sb.append("IMEI: ");
		sb.append(tm.getDeviceId());
		sb.append("\n");
		sb.append("Country: ");
		sb.append(tm.getNetworkCountryIso());
		sb.append("\n");
		sb.append("IMSI: ");
		sb.append(tm.getSubscriberId());
		sb.append("\n");
		sb.append("Operator: ");
		sb.append(tm.getNetworkOperatorName());
		sb.append("\n");
		sb.append("SIM serial: ");
		sb.append(tm.getSimSerialNumber());
		sb.append("\n");
		tvStatus.setText(sb.toString());
	}
}